@@ -1,5 +1,5 @@
 /*
- *  $Id: checklist.c,v 1.131 2011/10/15 12:43:07 tom Exp $
+ *  $Id: checklist.c,v 1.132 2011/10/20 23:38:07 tom Exp $
  *
  *  checklist.c -- implements the checklist box
  *
@@ -81,30 +81,30 @@ print_item(WINDOW *win,
     int limit;
 
     /* Clear 'residue' of last item */
-    wattrset(win, menubox_attr);
+    (void) wattrset(win, menubox_attr);
     (void) wmove(win, choice, 0);
     for (i = 0; i < list_width; i++)
 	(void) waddch(win, ' ');
 
     (void) wmove(win, choice, check_x);
-    wattrset(win, selected ? check_selected_attr : check_attr);
+    (void) wattrset(win, selected ? check_selected_attr : check_attr);
     (void) wprintw(win,
 		   (checkflag == FLAG_CHECK) ? "[%c]" : "(%c)",
 		   states[item->state]);
-    wattrset(win, menubox_attr);
+    (void) wattrset(win, menubox_attr);
     (void) waddch(win, ' ');
 
     if (strlen(item->name) != 0) {
 
 	indx = dlg_index_wchars(item->name);
 
-	wattrset(win, selected ? tag_key_selected_attr : tag_key_attr);
+	(void) wattrset(win, selected ? tag_key_selected_attr : tag_key_attr);
 	(void) waddnstr(win, item->name, indx[1]);
 
 	if ((int) strlen(item->name) > indx[1]) {
 	    limit = dlg_limit_columns(item->name, (item_x - check_x - 6), 1);
 	    if (limit > 1) {
-		wattrset(win, selected ? tag_selected_attr : tag_attr);
+		(void) wattrset(win, selected ? tag_selected_attr : tag_attr);
 		(void) waddnstr(win,
 				item->name + indx[1],
 				indx[limit] - indx[1]);
@@ -118,7 +118,7 @@ print_item(WINDOW *win,
 
 	if (limit > 0) {
 	    (void) wmove(win, choice, item_x);
-	    wattrset(win, selected ? item_selected_attr : item_attr);
+	    (void) wattrset(win, selected ? item_selected_attr : item_attr);
 	    dlg_print_text(win, item->text, cols[limit], &attr);
 	}
     }
@@ -126,7 +126,7 @@ print_item(WINDOW *win,
     if (selected) {
 	dlg_item_help(item->help);
     }
-    wattrset(win, save);
+    (void) wattrset(win, save);
 }
 
 /*
@@ -253,7 +253,7 @@ dlg_checklist(const char *title,
     dlg_draw_bottom_box2(dialog, border_attr, border2_attr, dialog_attr);
     dlg_draw_title(dialog, title);
 
-    wattrset(dialog, dialog_attr);
+    (void) wattrset(dialog, dialog_attr);
     dlg_print_autowrap(dialog, prompt, height, width);
 
     list_width = width - 6;
