@@ -1,5 +1,5 @@
 /*
- *  $Id: menubox.c,v 1.127 2011/10/17 00:49:25 tom Exp $
+ *  $Id: menubox.c,v 1.129 2011/10/20 21:15:36 tom Exp $
  *
  *  menubox.c -- implements the menu box
  *
@@ -88,7 +88,6 @@ print_tag(WINDOW *win,
     int prefix;
 
     indx = dlg_index_wchars(item->name);
-    limit = dlg_count_wchars(item->name);
     prefix = (indx[1] - indx[0]);
 
     /* highlight first char of the tag to be special */
@@ -695,7 +694,8 @@ dlg_menu(const char *title,
 		 */
 		if (result == DLG_EXIT_ERROR) {
 		    result = DLG_EXIT_UNKNOWN;
-		} else if (is_inputmenu) {
+		} else if (is_inputmenu
+			   || rename_menutext == dlg_dummy_menutext) {
 		    result = handle_button(result,
 					   items,
 					   scrollamt + choice);
