@@ -1,5 +1,5 @@
 /*
- *  $Id: msgbox.c,v 1.66 2011/06/27 08:36:28 tom Exp $
+ *  $Id: msgbox.c,v 1.68 2011/10/15 12:43:07 tom Exp $
  *
  *  msgbox.c -- implements the message box and info box
  *
@@ -95,13 +95,13 @@ dialog_msgbox(const char *title, const char *cprompt, int height, int width,
 
     dlg_mouse_setbase(x, y);
 
-    dlg_draw_box(dialog, 0, 0, height, width, dialog_attr, border_attr);
+    dlg_draw_box2(dialog, 0, 0, height, width, dialog_attr, border_attr, border2_attr);
     dlg_draw_title(dialog, title);
 
     wattrset(dialog, dialog_attr);
 
     if (pauseopt) {
-	dlg_draw_bottom_box(dialog);
+	dlg_draw_bottom_box2(dialog, border_attr, border2_attr, dialog_attr);
 	mouse_mkbutton(height - 2, width / 2 - 4, 6, '\n');
 	dlg_draw_buttons(dialog, height - 2, 0, buttons, button, FALSE, width);
 	dlg_draw_helpline(dialog, FALSE);
@@ -110,6 +110,7 @@ dialog_msgbox(const char *title, const char *cprompt, int height, int width,
 	    if (show) {
 		last = dlg_print_scrolled(dialog, prompt, offset,
 					  page, width, pauseopt);
+		dlg_trace_win(dialog);
 		show = FALSE;
 	    }
 	    key = dlg_mouse_wgetch(dialog, &fkey);
@@ -176,6 +177,7 @@ dialog_msgbox(const char *title, const char *cprompt, int height, int width,
 	dlg_print_scrolled(dialog, prompt, offset, page, width, pauseopt);
 	dlg_draw_helpline(dialog, FALSE);
 	wrefresh(dialog);
+	dlg_trace_win(dialog);
 	result = DLG_EXIT_OK;
     }
 
